==> haskell-base-orphans-0.8.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-base-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-orphans
version: 0.8.1
id: base-orphans-0.8.1-1eiH9qVb6AAEHB9dzgavFy
key: base-orphans-0.8.1-1eiH9qVb6AAEHB9dzgavFy
license: MIT
copyright: (c) 2012-2017 Simon Hengel,
           (c) 2014-2017 João Cristóvão,
           (c) 2015-2017 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
homepage: https://github.com/haskell-compat/base-orphans#readme
synopsis: Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in later versions of @base@ to a wider (older) range of compilers. @base-orphans@ does not export anything except the orphan instances themselves and complements @<http://hackage.haskell.org/package/base-compat base-compat>@.
    See the README for what instances are covered: <https://github.com/haskell-compat/base-orphans#readme>. See also the <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered> section.
category: Compatibility
abi: dd82264fb51499a4caca76b2b85d9441
exposed: True
exposed-modules:
    Data.Orphans
hidden-modules: Data.Orphans.Prelude
import-dirs: /usr/lib/ghc-8.6.5/site-local/base-orphans-0.8.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/base-orphans-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/base-orphans-0.8.1
hs-libraries: HSbase-orphans-0.8.1-1eiH9qVb6AAEHB9dzgavFy
depends:
    base-4.12.0.0 ghc-prim-0.5.3
haddock-interfaces: /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock
haddock-html: /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-orphans-0.8.1-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-base-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-orphans
version: 0.8.1
id: base-orphans-0.8.1-HeyTAcy4PKhDcGhjvJwDzq
key: base-orphans-0.8.1-HeyTAcy4PKhDcGhjvJwDzq
license: MIT
copyright: (c) 2012-2017 Simon Hengel,
           (c) 2014-2017 João Cristóvão,
           (c) 2015-2017 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
homepage: https://github.com/haskell-compat/base-orphans#readme
synopsis: Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in later versions of @base@ to a wider (older) range of compilers. @base-orphans@ does not export anything except the orphan instances themselves and complements @<http://hackage.haskell.org/package/base-compat base-compat>@.
    See the README for what instances are covered: <https://github.com/haskell-compat/base-orphans#readme>. See also the <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered> section.
category: Compatibility
abi: 1901fe31f35b502a5f892cd755d6776c
exposed: True
exposed-modules:
    Data.Orphans
hidden-modules: Data.Orphans.Prelude
import-dirs: /usr/lib/ghc-8.6.5/site-local/base-orphans-0.8.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/base-orphans-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/base-orphans-0.8.1
hs-libraries: HSbase-orphans-0.8.1-HeyTAcy4PKhDcGhjvJwDzq
depends:
    base-4.12.0.0 ghc-prim-0.5.3
haddock-interfaces: /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock
haddock-html: /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
